@@ -1,6 +1,6 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBackgroundImage {
     kind: BackgroundImage,
@@ -54,7 +54,7 @@ impl BackgroundImage {
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
         let out = match pattern {
             [] => Self::parse_arbitrary(arbitrary)?,
-            [s] if check_valid(s) => Self::Standard(s.to_string()),
+            [s] if Self::check_valid(s) => Self::Standard(s.to_string()),
             _ => return syntax_error!("Unknown bg-image instructions: {}", pattern.join("-")),
         };
         Ok(out)
@@ -63,10 +63,9 @@ impl BackgroundImage {
         debug_assert!(arbitrary.is_some());
         Ok(Self::Arbitrary(arbitrary.to_string()))
     }
-}
-
-/// <https://developer.mozilla.org/en-US/docs/Web/CSS/background-origin#syntax>
-fn check_valid(mode: &str) -> bool {
-    let set = BTreeSet::from_iter(vec!["inherit", "initial", "none", "revert", "unset"]);
-    set.contains(mode)
+    /// <https://developer.mozilla.org/en-US/docs/Web/CSS/background-origin#syntax>
+    pub fn check_valid(mode: &str) -> bool {
+        let set = BTreeSet::from_iter(vec!["inherit", "initial", "none", "revert", "unset"]);
+        set.contains(mode)
+    }
 }
