@@ -4,7 +4,8 @@ pub(crate) mod grid_auto;
 pub(crate) mod grid_cols;
 pub(crate) mod grid_flow;
 pub(crate) mod grid_rows;
-///
+
+#[doc=include_str!("readme.md")]
 #[derive(Debug, Clone, Copy)]
 pub struct TailwindGrid {}
 
