@@ -39,7 +39,7 @@ impl TailwindSelect {
     }
     /// https://developer.mozilla.org/en-US/docs/Web/CSS/user-select#syntax
     pub fn check_valid(mode: &str) -> bool {
-        let set = BTreeSet::from_iter(vec!["none", "auto", "text", "contain", "all", "inherit", "initial"]);
+        let set = BTreeSet::from_iter(vec!["all", "auto", "contain", "inherit", "initial", "none", "revert", "text", "unset"]);
         set.contains(mode)
     }
 }
