@@ -1,6 +1,6 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Copy, Clone, Debug, Default)]
 pub struct TailwindContainer {}
 
@@ -10,4 +10,8 @@ impl Display for TailwindContainer {
     }
 }
 
-impl TailwindInstance for TailwindContainer {}
+impl TailwindInstance for TailwindContainer {
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        BTreeSet::new()
+    }
+}
