@@ -1,7 +1,7 @@
 use super::*;
 use crate::KeywordOnly;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindEase {
     kind: KeywordOnly,
@@ -17,28 +17,27 @@ impl Display for TailwindEase {
 impl TailwindEase {
     /// https://tailwindcss.com/docs/transition-timing-function
     pub fn parse(kind: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: KeywordOnly::parser("ease", &check_valid)(kind, arbitrary)? })
+        Ok(Self { kind: KeywordOnly::parser("ease", &Self::check_valid)(kind, arbitrary)? })
     }
     /// https://tailwindcss.com/docs/transition-timing-function#arbitrary-values
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
         Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
     }
-}
-
-/// https://developer.mozilla.org/en-US/docs/Web/CSS/transition-timing-function#syntax
-fn check_valid(mode: &str) -> bool {
-    let set = BTreeSet::from_iter(vec![
-        "ease",
-        "ease-in",
-        "ease-in-out",
-        "ease-out",
-        "inherit",
-        "initial",
-        "linear",
-        "revert",
-        "step-end",
-        "step-start",
-        "unset",
-    ]);
-    set.contains(mode)
+    /// https://developer.mozilla.org/en-US/docs/Web/CSS/transition-timing-function#syntax
+    pub fn check_valid(mode: &str) -> bool {
+        let set = BTreeSet::from_iter(vec![
+            "ease",
+            "ease-in",
+            "ease-in-out",
+            "ease-out",
+            "inherit",
+            "initial",
+            "linear",
+            "revert",
+            "step-end",
+            "step-start",
+            "unset",
+        ]);
+        set.contains(mode)
+    }
 }
