@@ -1,6 +1,6 @@
 use super::*;
 
-#[doc = include_str!("readme.md")]
+#[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindFontSize {
     name: String,
@@ -12,4 +12,8 @@ impl Display for TailwindFontSize {
     }
 }
 
-impl TailwindInstance for TailwindFontSize {}
+impl TailwindInstance for TailwindFontSize {
+    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        todo!()
+    }
+}
