@@ -1,99 +1,34 @@
+use std::{collections::BTreeSet, fmt::Debug};
+
+use crate::{systems::instruction::TailwindInstruction, *};
+
 mod methods;
 mod setter;
-use crate::{systems::instruction::TailwindInstruction, *};
-use std::{collections::BTreeSet, fmt::Debug};
 
 #[derive(Debug)]
 pub struct TailwindBuilder {
-    // pub apply: BTreeMap<String, CssAttributes>,
+    /// Whether to enable class name confusion
     pub obfuscate: bool,
-    pub objects: BTreeSet<Box<dyn TailwindInstance>>,
+    ///
+    pub objects: BTreeSet<CssInstance>,
+    ///
     pub preflight: PreflightSystem,
+    /// All dynamic color properties
+    ///
+    /// Only determined when packing
     pub palettes: PaletteSystem,
+    /// All dynamic break points
+    ///
+    /// Only determined when packing
     pub screens: BreakPointSystem,
+    /// All dynamically registered font properties
+    ///
+    /// Only determined when packing
     pub fonts: FontSystem,
 }
 
 impl TailwindBuilder {
-    /// ## Inline mode(no bundle)
-    ///
-    ///
-    /// # Returns
-    ///
-    /// - Anonymous style sheets, which can be placed inside `style` tags
-    ///
-    /// ## Example
-    /// - input
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// ```
-    /// - output
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// <style> {} </style>
-    /// ```
-    #[inline]
-    #[cfg_attr(not(debug_assertions), track_caller)]
-    pub fn trace(&mut self, style: &str) -> String {
-        self.try_trace(style).unwrap()
-    }
-    /// Safe version of [`TailwindBuilder::trace`]
-    pub fn try_trace(&mut self, style: &str) -> Result<String> {
-        let parsed = parse_tailwind(style)?;
-        let out: Vec<String> = parsed.iter().map(|s| s.id()).collect();
-        for i in parsed.into_iter() {
-            self.objects.insert(i.get_instance()?);
-        }
-        Ok(out.join(" "))
-    }
-
-    /// ## Inline mode(no bundle)
-    ///
-    ///
-    /// # Returns
-    ///
-    /// - Anonymous style sheets, which can be placed inside `style` tags
-    ///
-    /// ## Example
-    /// - input
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// ```
-    /// - output
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// <style> {} </style>
-    /// ```
-    #[inline]
-    #[cfg_attr(not(debug_assertions), track_caller)]
-    pub fn scope(&self, style: &str) {
-        let _id = style;
-    }
-    /// Safe version of [`TailwindBuilder::scope`]
-    pub fn try_scope() {}
-
-    /// ## Inline mode(no bundle)
-    ///
-    ///
-    /// # Returns
-    ///
-    /// - Anonymous style sheets, which can be placed inside `style` tags
-    ///
-    /// ## Example
-    /// - input
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// ```
-    /// - output
-    /// ```html
-    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
-    /// <style> {} </style>
-    /// ```
-    #[inline]
-    #[cfg_attr(not(debug_assertions), track_caller)]
-    pub fn dataset() {}
-
-    /// ## Inline mode(no bundle)
+    /// ## Trace mode
     ///
     ///
     /// # Returns
@@ -112,36 +47,53 @@ impl TailwindBuilder {
     /// <style> {} </style>
     /// ```
     #[inline]
-    #[cfg_attr(not(debug_assertions), track_caller)]
-    pub fn inline(&mut self, style: &str) -> String {
-        self.try_inline(style).unwrap()
+    #[track_caller]
+    pub fn trace(&mut self, style: &str) -> CssBundle {
+        self.interpret(style, None).unwrap()
+    }
+    /// ## Inline mode
+    ///
+    ///
+    /// # Returns
+    /// **Not all instructions can be inline, if not, it will fall back to trace mode**
+    ///
+    /// - Anonymous style sheets, which can be placed inside `style` tags
+    ///
+    /// ## Example
+    /// - input
+    /// ```html
+    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
+    /// ```
+    /// - output
+    /// ```html
+    /// <div class="p-auto px-px pt-2 pb-2">Test</div>
+    /// <style> {} </style>
+    /// ```
+    #[inline]
+    #[track_caller]
+    pub fn inline(&mut self, style: &str) -> CssBundle {
+        self.interpret(style, Some(InlineMode::Inline)).unwrap()
     }
     /// Safe version of [`TailwindBuilder::inline`]
-    pub fn try_inline(&mut self, style: &str) -> Result<String> {
+    pub fn interpret(&mut self, style: &str, mode: Option<InlineMode>) -> Result<CssBundle> {
         let parsed = parse_tailwind(style)?;
-        let mut set = BTreeSet::new();
+        let mut out = CssBundle::default();
         for item in parsed {
-            // match item.inlineable() {
-            //     true => {}
-            //     false => {}
-            // }
-            set.extend(item.attributes(self))
+            let i = CssInstance::new(&*item.get_instance()?, self);
+            out.insert(i.clone());
+            self.objects.insert(i);
         }
-        let vec: Vec<_> = set.into_iter().map(|s| s.to_string()).collect();
-        Ok(vec.join(""))
+        out.set_inline(mode.unwrap_or_default());
+        Ok(out)
     }
     /// Bundle all used stylesheets
-    #[inline]
-    #[cfg_attr(not(debug_assertions), track_caller)]
-    pub fn bundle(&self) -> String {
-        self.try_bundle(1024 * 10).unwrap()
-    }
-    /// Safe version of [`TailwindBuilder::bundle`]
-    pub fn try_bundle(&self, cap: usize) -> Result<String> {
-        let mut out = String::with_capacity(cap);
-        self.preflight.write_css(&mut out, self)?;
+    pub fn bundle(&self) -> Result<String> {
+        let mut out = String::with_capacity(1024 * 10);
+        if !self.preflight.disable {
+            out.push_str(&self.preflight.to_string());
+        }
         for item in &self.objects {
-            item.write_css(&mut out, self)?;
+            item.write_css(&mut out)?;
         }
         Ok(out)
     }
